@@ -3,5 +3,7 @@
 
 fn main() {
     #[static_assert_]
+    #[warn(static_assert)]
+    #[allow(dead_code)]
     const TEST: bool = false;
 }
